==> glpi-10.0.11.tgz: glpi/install/migrations/update_10.0.3_to_10.0.4/config.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2023 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

/**
 * @var \Migration $migration
 */

// CAS version config was missing on fresh installations since GLPI 9.4.0
$migration->addConfig(['cas_version' => 'CAS_VERSION_2_0']);

$should_inventory_be_enabled = 0; //default value
if (countElementsInTable(\Agent::getTable()) > 0) {
    $should_inventory_be_enabled = 1;
}
$migration->addConfig(['enabled_inventory' => $should_inventory_be_enabled], 'inventory');

==> glpi-10.0.16.tgz: glpi/install/migrations/update_10.0.15_to_10.0.16/config.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2024 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

/**
 * @var \DBmysql $DB
 * @var \Migration $migration
 */
global $DB, $migration;

// Attach existing mail configuration settings log to NotificationMailingSetting object
$or_criteria = [];
foreach (NotificationMailingSetting::getRelatedConfigKeys() as $field) {
    // `old_value` starts with the field name, followed by a space, then the field value
    $or_criteria[] = [
        'old_value' => ['LIKE', $field . '\\ %']
    ];
}
$migration->addPostQuery(
    $DB->buildUpdate(
        'glpi_logs',
        [
            'itemtype' => 'NotificationMailingSetting',
            'id_search_option' => 1,
        ],
        [
            'itemtype' => 'Config',
            'OR' => $or_criteria,
        ]
    )
);
